package com.akamai.mdt.id3tag;

import android.app.Activity;
import android.content.DialogInterface;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.view.WindowManager;
import android.widget.ProgressBar;
import android.widget.TextView;

import com.akamai.id3tagextractor.ID3TagData;
import com.akamai.id3tagextractor.ID3TagEventListener;
import com.akamai.id3tagextractor.ID3TagExtractorMessageHandler;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;

public class MainActivity extends Activity implements View.OnTouchListener, DialogInterface.OnCancelListener, IPlayerEventsListener, ID3TagEventListener {

    private VideoPlayerContainer mVideoContainer;

    private VideoPlayerView mVideoView;

    private ProgressBar mProgressBar;

    private TextView tagsTextView;

    private boolean mWasPlaying = false;

    private MediaResource resource;

    private int mCurrentPosition = 0;

    private final static String LICENSE = "YBtTdxkeJSzAyCfQg2THAmpH95eMusF0mdDWj0jlz0dd9Rrg7k9siyzrGf8lv1S3dPXoGouM7jnG7qN33x5k-Q==";

    private final static String VIDEO_URL = "http://sblanco.mediadev.edgesuite.net/id3/master.m3u8";

    private ID3TagExtractorMessageHandler mId3TagExtractorMessageHandler;


    @Override
    public boolean onFoundID3TagData(ID3TagData data) {
        String id3Tag = data.getText();
        Log.i("AMP ID3 Tags Sample", id3Tag);
        String msg = "ID3 Tag: <" + id3Tag + ">\n" + "(There should be no video)";
        tagsTextView.setText(msg);
        return true;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // This prevents the device to go sleep
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        // Initialize the progress bar with the xml
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);

        // Get a reference to the VideoContainer object
        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);

        tagsTextView = (TextView) findViewById(R.id.tagsTextView);

        mVideoContainer.addVideoPlayerContainerCallback(new VideoPlayerContainer.VideoPlayerContainerCallback() {
            @Override
            public void onVideoPlayerCreated() {

            }

            @Override
            public void onResourceReady(MediaResource mediaResource) {

                resource = mediaResource;
                // Get a reference to the VideoView object
                mVideoView = mVideoContainer.getVideoPlayer();

                // Set the progress to the player
                mVideoView.setProgressBarControl(mProgressBar);

                // Set your license
                mVideoView.setLicense(LICENSE);

                // Set the screen mode
                mVideoView.setFullScreen(true);
                mVideoView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);

                // Activate the logs
                mVideoView.setLogEnabled(true);

                // Configure the ID3Tag extractor
                mId3TagExtractorMessageHandler = new ID3TagExtractorMessageHandler();
                mId3TagExtractorMessageHandler.setVideoPlayerView(mVideoView);
                mId3TagExtractorMessageHandler.addEventListener(MainActivity.this);

                // Play the video
                mVideoView.play(resource);
            }

            @Override
            public void onResourceError() {

            }
        });
        mVideoContainer.prepareResource(VIDEO_URL);
    }

    @Override
    protected void onResume() {
        Log.d("PlayerView", "OnResume");
        if (mWasPlaying) {
            mVideoView.play(resource, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d("PlayerView", "OnPause");
        if (mVideoView.isPlaying() || mVideoView.isPaused()) {
            mCurrentPosition = mVideoView.getTimePosition();
            mWasPlaying = true;
        }
        mVideoView.stop();
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d("PlayerView", "OnDestroy");
        mVideoView.stop();
        mVideoView.onDestroy();
        super.onDestroy();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        if (iInEventType == IPlayerEventsListener.PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED)
            Log.d("Player", "Event Type: PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDED (" + iInEventType + ")");

        return true;
    }

    @Override
    public void onCancel(DialogInterface dialog) {
        finish();
    }

    @Override
    public boolean onTouch(View v, MotionEvent event) {
        return false;
    }

}
